import service from '@/service'
import { removeToken } from '@/utils'
import router from '@/router'

export const login = (data) => {
    return service({
        method: 'post',
        url: '/auth/create_token',
        data
    })
}

export const logout = () => {
    removeToken()
    router.push('/login')
}

export const verifyToken = (data) => {
    return service({
        method: 'post',
        url: '/auth/verify_token',
        data
    })
}

export const uploadImage = (file) => {
    let form_data = new FormData()
    form_data.append('image',file.file)
    return service({
        method: 'post',
        url: '/utility/uploadImage',
        data: form_data
    })
}

export const selfInfo = (data={}) => {
    return service({
        method: 'post',
        url: '/order/getadmininfo',
        data
    })
}

export const creatorInfo = (id) => {
    return service({
        method: 'post',
        url: '/preorder/getoperatorinfo/' + id,
    })
}

export const getProduct = (id) => {
    return service({
        method: 'post',
        url: '/product/product?id=' + id 
    })
}

export const hasProduct = (brand,code) => {
    return service({
        method: 'post',
        url: '/product/hasproduct',
        data: {
            code: code,
            brand: brand
        }
    })
}

export const hasBrandProduct = (brand,code) => {
    return service({
        method: 'post',
        url: '/product/hasbrandproduct',
        data: {
            code: code,
            brand: brand
        }
    })
}

export const searchProduct = (code) => {
    return service({
        method: 'post',
        url: '/product/searchproductbycode/' + code
    })
}

export const brandList = () => {
    return service({
        method: 'post',
        url: '/accessory/brandList',
    })
}

export const searchBrand = (keyword) => {
    return service({
        method: 'post',
        url: '/accessory/searchbrand/' + keyword
    })
}

export const isBrandName = (keyword) => {
    return service({
        method: 'post',
        url: '/accessory/isbrandname/' + keyword
    })
}

export const sellerList = () => {
    return service({
        method: 'post',
        url: '/accessory/sellerlist/'
    })
}

export const shopList = (ids) => {
    return service({
        method: 'post',
        url: '/accessory/shoplist',
        data: {
            ids
        }
    })
}

export const searchSeller = (keyword) => {
    return service({
        method: 'post',
        url: '/accessory/searchseller/' + keyword
    })
}

export const sellerInfo = (id) => {
    return service({
        method: 'post',
        url: '/accessory/sellerinfo/' + id
    })
}

export const searchGoods = (keyword) => {
    return service({
        method: 'post',
        url: '/sellergoods/searchgoods/' + keyword
    })
}

export const productInfo = (id) => {
    return service({
        method: 'post',
        url: '/product/product?id=' + id
    })
}

export const goodsInfo = (id) => {
    return service({
        method: 'post',
        url: '/sellergoods/goodsinfo/' + id
    })
}

export const orderCustomer = () => {
    return service({
        method: 'post',
        url: '/preorder/orderCustomerList'
    })
}

export const orderCreator = () => {
    return service({
        method: 'post',
        url: '/preorder/orderCreatorList'
    })
}

export const orderSeller = () => {
    return service({
        method: 'post',
        url: '/preorder/orderSellerList'
    })
}

export const searchMember = (keyword) => {
    return service({
        method: 'post',
        url: '/member/matchmember/' + keyword
    })
}

export const memberInfo = (id) => {
    return service({
        method: 'post',
        url: '/member/memberinfo/' + id
    })
}

export const setMemberAddress = (id,data) => {
    return service({
        method: 'post',
        url: '/member/setmemberaddress/' + id,
        data
    })
}

export const orderList = (data) => {
    return service({
        method: 'post',
        url: '/order/orderList',
        data
    })
}

export const orderFilter = (keys,page=1,page_size=20) => {
    return service({
        method: 'post',
        url: '/preorder/filter',
        data: {
            page,
            page_size,
            keys
        }
    })
}

export const orderFilter_v2 = (keys,page=1,page_size=20) => {
    return service({
        method: 'post',
        url: '/preorder/filter_v2',
        data: {
            page,
            page_size,
            keys
        }
    })
}

export const orderInfo = () => {
    return service({
        method: 'post',
        url: '/preorder/orderNumber'
    })
}

export const countSearchProduct = () => {
    return service({
        method: 'get',
        url: '/product/countSearchProduct'
    })
}

export const countCustomerOrder = () => {
    return service({
        method: 'get',
        url: '/preorder/countCustomerOrder'
    })
}

export const monthProduct = (year=0) => {
    return service({
        method: 'get',
        url: '/product/monthProduct/' + year
    })
}

export const monthGoods = (year=0) => {
    return service({
        method: 'get',
        url: '/product/monthGoods/' + year
    })
}

export const getAnnouncementList = () => {
    return service({
        method: 'get',
        url: '/accessory/getAnnouncementList'
    })
}

export const $orderList = (page=1,page_size=20,name='',status=0) => {
    return service({
        method: 'post',
        url: '/preorder/list',
        data: {
            page,
            page_size,
            key: {
                name,
                status

            }
        }
    })
}

export const $orderInfo = (id) => {
    return service({
        method: 'post',
        url: '/preorder/info/' + id,
    })
}

export const $orderStatus = (ids) => {
    return service({
        method: 'post',
        url: '/preorder/orderstatus',
        data: {
            ids: ids
        }
    })
}

export const $createOrder = (user_id,seller_id,note='',creator,subject='') => {
    let data = {
        user_id,
        seller_id,
        creator
    }
    if(note) {
        data.note = note
    }
    if(subject) {
        data.subject = subject
    }
    return service({
        method: 'post',
        url: '/preorder/create/',
        data
    })
}

export const $updateOrder = (id,data) => {
    return service({
        method: 'post',
        url: '/preorder/update/' + id,
        data
    })
}

export const $removeOrder = (id) => {
    return service({
        method: 'post',
        url: '/preorder/remove/' + id
    })
}

export const $batchRemove = (data) => {
    return service({
        method: 'post',
        url: '/preorder/batchremove',
        data
    })
}

export const $orderGoods = (id) => {
    return service({
        method: 'post',
        url: '/preorder/ordergoods/' + id,
    })
}

export const $addOrderGoods = (id,data) => {
    return service({
        method: 'post',
        url: `/preorder/addgoods/${id}`,
        data
    })
}

export const $orderInquiry = (orderid) => {
    return service({
        method: 'post',
        url: '/preorder/orderinquiry/' + orderid,
    })
}

export const $enquiryReturn = (id,product,token) => {
    return service({
        method: 'post',
        url: '/preorder/enquiry_return/' + id,
        data: {
            product: product,
            token: token,
            id: id
        }
    })
}

export const $createInquiry = (orderid,data) => {
    return service({
        method: 'post',
        url: '/preorder/createinquiry/' + orderid,
        data
    })
}

export const $makeOrderOffer = (orderid,data) => {
    return service({
        method: 'post',
        url: '/preorder/order_offer/' + orderid,
        data
    })
}

export const $orderEnqueryResult = (order_id) => {
    return service({
        method: 'post',
        url: '/preorder/orderEnquiryResult/' + order_id,
    })
}

export const getSupplierContact = (id) => {
    return service({
        method: 'post',
        url: '/supplier/contactList/' + id,
    })
}

export const $sendLink = (id,contact=0) => {
    return service({
        method: 'get',
        url: '/preorder/sendlink/' + id + '?contact=' + contact,
    })
}

export const getUserOrder = (orderid) => {
    return service({
        method: 'post',
        url: '/preorder/get_user_order/' + orderid,
    })
}

export const $getOrderOffer = (orderid) => {
    return service({
        method: 'post',
        url: '/preorder/get_order_offer/' + orderid,
    })
}

export const $actionLog = (order_id,user,action,note='') => {
    return service({
        method: 'post',
        url: `/preorder/action_log`,
        data: {order_id,action,user,note}
    })
}

export const getActionLog = (order_id) => {
    return service({
        method: 'post',
        url: `/preorder/getactionlog/${order_id}`,
    })
}

export const preorderList = (data) => {
    return service({
        method: 'post',
        url: '/order/preorderlist',
        data
    })
}

export const getOrderStatus = (ids) => {
    return service({
        method: 'post',
        url: '/order/orderstatus',
        data: {
            ids: ids
        }
    })
}

export const preorder = (id) => {
    return service({
        method: 'post',
        url: '/preorder/info/' + id,
    })
}

export const getOrders = (ids) => {
    return service({
        method: 'post',
        url: '/preorder/getOrders',
        data: {
            ids
        }
    })
}

export const orderToday = () => {
    return service({
        method: 'get',
        url: '/preorder/todayOrder',
    })
}

export const focusList = () => {
    return service({
        method: 'post',
        url: '/preorder/focuslist',
    })
}

export const focusOrderList = (code,brand) => {
    return service({
        method: 'get',
        url: '/preorder/focusOrderlist',
        params: {
            code,
            brand
        }
    })
}

export const focusItem = (id) => {
    return service({
        method: 'get',
        url: '/preorder/focus_item/' + id,
    })
}

export const focusProduct = (id) => {
    return service({
        method: 'get',
        url: '/preorder/focusproduct?id=' + id,
    })
}

export const updateFocus = (data) => {
    return service({
        method: 'post',
        url: '/preorder/updatefocus',
        data
    })
}

export const topFocus = (id) => {
    return service({
        method: 'post',
        url: '/preorder/topfocus?id=' + id,
    })
}

export const focusOrder = (id,order_id) => {
    return service({
        method: 'get',
        url: `/preorder/focusorder?id=${id}&order_id=${order_id}`,
    })
}

export const hasFocus = (brand,code) => {
    return service({
        method: 'get',
        url: `/preorder/hasfocus?brand=${brand}&code=${code}`,
    })
}

export const addFocusLog = (id,user_id,note) => {
    return service({
        method: 'post',
        url: '/preorder/addfocuslog?id=' + id,
        data: {
            note,
            operator: user_id,
        }
    })
}

export const deleteFocusItem = (id) => {
    return service({
        method: 'post',
        url: '/preorder/deleteFocusItem/' + id,
    })
}

export const preorderGoods = (id) => {
    return service({
        method: 'post',
        url: '/order/getpreordergoods/' + id,
    })
}

export const update_order = (id,data) => {
    return service({
        method: 'post',
        url: '/order/updateorder/' + id,
        data
    })
}

export const createOrder = (userid,data) => {
    return service({
        method: 'post',
        url: '/order/createorder/' + userid,
        data
    })
}

export const orderInquiry = (orderid) => {
    return service({
        method: 'post',
        url: '/order/orderinquiry/' + orderid,
    })
}

export const createInquiry = (orderid,data) => {
    return service({
        method: 'post',
        url: '/order/createinquiry/' + orderid,
        data
    })
}

export const enquiryReturn = (id,product,token) => {
    return service({
        method: 'post',
        url: '/order/enquiry_return/' + id,
        data: {
            product: product,
            token: token,
            id: id
        }
    })
}

export const orderEnqueryResult = (order_id) => {
    return service({
        method: 'post',
        url: '/order/orderEnquiryResult/' + order_id,
    })
}

export const makeOrderOffer = (orderid,data) => {
    return service({
        method: 'post',
        url: '/order/order_offer/' + orderid,
        data
    })
}

export const getOrderOffer = (orderid) => {
    return service({
        method: 'post',
        url: '/order/get_order_offer/' + orderid,
    })
}

export const makeOrderShop = (order_id,data) => {
    return service({
        method: 'post',
        url: '/order/order_shop/' + order_id,
        data
    })
}

export const sendLink = (id) => {
    return service({
        method: 'post',
        url: '/order/sendlink/' + id,
    })
}

export const supplierList = () => {
    return service({
        method: 'post',
        url: `/member/supplierlist/`,
    })
}

export const Suppliers = (ids) => {
    return service({
        method: 'post',
        url: `/member/suppliers`,
        data: {
            ids
        }
    })
}

export const supplierInfo = (id) => {
    return service({
        method: 'get',
        url: `/member/supplierId/${id}`,
    })
}

export const searchSupplier = (key) => {
    return service({
        method: 'post',
        url: `/member/searchSupplier/${key}`,
    })
}

export const getOrder = (id) => {
    return service({
        method: 'post',
        url: `/order/getorder/${id}`,
    })
}

export const getOrderLog = (id) => {
    return service({
        method: 'post',
        url: `/order/getorderlog/${id}`,
    })
}

export const addOrderGoods = (id,data) => {
    return service({
        method: 'post',
        url: `/order/addordergoods/${id}`,
        data
    })
}

export const getDeliveryDoc = (id) => {
    return service({
        method: 'post',
        url: `/order/getdeliverydoc/${id}`,
    })
}

export const updateOrder = (id,data) => {
    return service({
        method: 'post',
        url: `/order/update/${id}`,
        data
    })
}

export const setTradeInfo = (id,data) => {
    return service({
        method: 'post',
        url: `/order/settradeinfo/${id}`,
        data
    })
}

export const setOrderDate = (id,data) => {
    return service({
        method: 'post',
        url: `/order/setorderdate/${id}`,
        data
    })
}

export const setContact = (id,data) => {
    return service({
        method: 'post',
        url: `/order/setcontact/${id}`,
        data
    })
}

export const syncContact = (user_id,data) => {
    return service({
        method: 'post',
        url: `/order/synccontact/${user_id}`,
        data
    })
}

export const areaTree = () => {
    return service({
        method: 'post',
        url: '/accessory/getareatree',
    })
}

export const areaChildren = (id) => {
    return service({
        method: 'post',
        url: '/accessory/getareachildren/' + id,
    })
}

export const areaName = (area) => {
    return service({
        method: 'post',
        url: `/accessory/areaname/${area}`,
    })
}

export const sendUserNotice = (openid,order_no,order_time) => {
    return service({
        method: 'post',
        url: `/weixin/sendTemplateMessage`,
        data: {
            openid,
            templateid: 'lljoAxfZrz2avjSCCdaJi1bDSjPkhVEai4w1pHHm9Ec',
            data: {
                time2: {value: order_time},
                character_string1: {value: order_no},
                thing3: {value: "联系信息不全，无法回复询盘订单申请"},
                const9: {value: '绑定您的联系电话'},
            },
        }
    })
}