import {createRouter,createWebHashHistory} from 'vue-router'
import { getToken } from '@/utils'

const routes = [
    {
        path: '/',
        redirect: '/login'
    },{
        path: '/login',
        name: 'Login',
        meta: {title: '登录'},
        component: () => import('../views/login.vue')
    },{
        path: '/home',
        name: 'Home',
        meta: {title: '首页'},
        component: () => import('../views/home/index.vue'),
        children: [
            {
                path: '/start',
                name: 'start',
                meta: {title: '信息看板'},
                component: () => import('../views/home/home.vue')
            },{
                path: '/order-info',
                name: 'order-info',
                meta: {title: '询盘统计分析'},
                component: () => import('../views/preorder/views.vue')
            },{
                path: '/order-list',
                name: 'order-list',
                meta: {title: '询盘商品明细'},
                component: () => import('../views/preorder/orderlist.vue')
            },{
                path: '/pre-order',
                name: 'pre-order',
                meta: {title: '询盘订单'},
                component: () => import('../views/preorder/index.vue'),
                children: [
                    {
                        path: 'list',
                        name: 'pre-order-list',
                        meta: {title: '列表'},
                        component: () => import('../views/preorder/list.vue')
                    },{
                        path: 'edit',
                        name: 'pre-order-edit',
                        meta: {title: '询盘订单处理'},
                        component: () => import('../views/preorder/edit.vue')
                    },
                ]
            },{
                path: '/trace',
                name: 'trace',
                meta: {title: '大件跟踪'},
                component: () => import('../views/trace.vue')
            },{
                path: '/setup',
                name: 'Setup',
                meta: {title: '系统设定'},
                component: () => import('../views/setup/index.vue'),
                children: [
                    // {
                    //     path: 'info',
                    //     name: 'Info',
                    //     meta: {title: '关于系统'},
                    //     component: () => import('../views/setup/about.vue')
                    // },{
                    //     path: 'log',
                    //     name: 'Log',
                    //     meta: {title: '操作日志'},
                    //     component: () => import('../views/setup/log.vue')
                    // },{
                    //     path: 'user',
                    //     name: 'User0',
                    //     meta: {title: '用户设定'},
                    //     component: () => import('../views/setup/user.vue')
                    // },{
                    //     path: 'user/:name/:age',
                    //     name: 'User',
                    //     meta: {title: '用户设定'},
                    //     component: () => import('../views/setup/user.vue')
                    // },
                ]
            },
        ]
    },
]

const router = createRouter({
    history: createWebHashHistory(),
    routes
})

// 登录之前做一个判断 ,判断它进入其它页面有没有先登录,
router.beforeEach((to, from, next) => {
    // 判断有没有登录
    const isLogin = getToken() ? true : false;
    // 如果当前访问的是登录页面或者注册页面可以让它进入
    if (to.path == '/login' || to.path == "/register") {
        next()
    } else {
        // 如果isLogin为true表示已经登录了;就让它正常进入就可以 ,如果没登录就让他进入登录页面
        isLogin ? next() : next('/')
    }
})

export default router